@@ -15,6 +15,7 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+from copy import copy
 from pathlib import Path
 
 from numpy import vstack
@@ -53,7 +54,7 @@ def create_file_reader(input_files, topology, featurizer, chunksize=None, **kw):
     if (isinstance(input_files, str)
             or (isinstance(input_files, (list, tuple))
                 and (any(isinstance(item, str) for item in input_files)
-                     or len(input_files) is 0))):
+                     or len(input_files) == 0))):
         reader = None
         # check: if single string create a one-element list
         if isinstance(input_files, str):
@@ -61,7 +62,7 @@ def create_file_reader(input_files, topology, featurizer, chunksize=None, **kw):
         elif len(input_files) > 0 and all(isinstance(item, str) for item in input_files):
             input_list = input_files
         else:
-            if len(input_files) is 0:
+            if len(input_files) == 0:
                 raise ValueError("The passed input list should not be empty.")
             else:
                 raise ValueError("The passed list did not exclusively contain strings or was a list of lists "
@@ -130,9 +131,9 @@ def single_traj_from_n_files(file_list, top):
         if isinstance(ff, Path):
             ff = str(ff.resolve())
         if traj is None:
-            traj = md.load(ff, top=top)
+            traj = md.load(copy(ff), top=top)
         else:
-            traj = traj.join(md.load(ff, top=top))
+            traj = traj.join(md.load(copy(ff), top=top))
 
     return traj
 
